summaryrefslogtreecommitdiffstats
path: root/knewstuff/provider.h
diff options
context:
space:
mode:
Diffstat (limited to 'knewstuff/provider.h')
-rw-r--r--knewstuff/provider.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/knewstuff/provider.h b/knewstuff/provider.h
index 6a0972319..98b5b7def 100644
--- a/knewstuff/provider.h
+++ b/knewstuff/provider.h
@@ -169,16 +169,16 @@ class KDE_EXPORT Provider
* the main provider database for this specific application.
* It should probably not be used directly by the application.
*/
-class KDE_EXPORT ProviderLoader : public QObject
+class KDE_EXPORT ProviderLoader : public TQObject
{
Q_OBJECT
public:
/**
* Constructor.
*
* @param parentWidget the parent widget
*/
- ProviderLoader( TQWidget *parentWidget );
+ ProviderLoader( TQWidget *tqparentWidget );
/**
* Starts asynchronously loading the list of providers of the
@@ -169,16 +169,16 @@ class KDE_EXPORT Provider
* Constructor.
*
- * @param parentWidget the parent widget
+ * @param tqparentWidget the parent widget
*/